summaryrefslogtreecommitdiffstats
path: root/ipc
diff options
context:
space:
mode:
Diffstat (limited to 'ipc')
-rw-r--r--ipc/ipc_message_start.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/ipc/ipc_message_start.h b/ipc/ipc_message_start.h
index 1eda50a..1cec310 100644
--- a/ipc/ipc_message_start.h
+++ b/ipc/ipc_message_start.h
@@ -116,9 +116,10 @@ enum IPCMessageStart {
CastMediaMsgStart,
AwMessagePortMsgStart,
GuestViewMsgStart,
// Note: CastCryptoMsgStart reserved for Chromecast internal code.
// Contact gunsch@ before changing/removing.
CastCryptoMsgStart,
+ CastChannelMsgStart,
DataReductionProxyStart,
ContentSettingsMsgStart,
LastIPCMsgStart // Must come last.
@@ -116,9 +116,10 @@ enum IPCMessageStart {
AwMessagePortMsgStart,
GuestViewMsgStart,
- // Note: CastCryptoMsgStart reserved for Chromecast internal code.
- // Contact gunsch@ before changing/removing.
+ // Note: CastCryptoMsgStart and CastChannelMsgStart reserved for Chromecast
+ // internal code. Contact gunsch@ before changing/removing.
CastCryptoMsgStart,